@@ -1362,14 +1362,15 @@ class CorrelationEditor:
                 self.info = self.tool_obj.description
 
         toolimpls = list()
-        tool_source_files = glob.glob("ceplugins/*.py")
+        tool_source_files = glob.glob(cfg.root+"ceplugins/*.py")
+        print(tool_source_files)
         for toolsrc in tool_source_files:
             if "custom_tool_template" in toolsrc or "__init__.py" in toolsrc:
                 continue
 
             module_name = toolsrc[toolsrc.rfind("\\")+1:-3]
             try:
-                mod = importlib.import_module("ceplugins."+module_name)
+                mod = importlib.import_module("scNodes.ceplugins."+module_name)
                 toolimpls.append(ToolImpl(mod.create))
             except Exception as e:
                 cfg.set_error(e, f"No well-defined Plugin found in {toolsrc}. See manual for minimal code requirements.")
